PlotX 3D Interactive Demo

Loading PlotX 3D Interactive Demo...

# 🎮 PlotX 3D

Interactive Visualization Platform

## 📷 Camera Controls

## 🎯 Selection Mode

## 🔧 Transform Mode

## 🎬 Animation

## ⚙️ Settings

Objects: 25 Speed: 1.0x
FPS: 60
Objects: 25
Selected: 0

### 🎮 Controls

- 🖱️ Mouse Drag: Rotate view
- 🔍 Mouse Wheel: Zoom in/out
- 🖱️ Right Click: Pan view
- 👆 Click Object: Select/deselect
- 📦 Shift+Drag: Box selection
- ⌨️ WASD: Fly camera movement
- ⌨️ Space: Jump (FPS mode)
- 🎯 G: Toggle gizmos
- 🔄 R: Reset view